function instrument = hCOMMOpenConnection(address, port, timeout)
%instrument = hCOMMOpenConnection(address, port, timeout)
%Opens a new TCP connection to a Hyperion instrument.
%
%Parameters:
%address - the IP address of the target Hyperion instrument
%port - String containing the type of port to open.  Possible values are:
    %commandPort - Opens a connection for normal communication with the
    %instrument.
    %peakStream - Opens a connection for streaming of peak data
    %spectrumStream - Opens a connection for streaming of full spectrum
    %data.
%timeout - specifies the maximum amount of time, in seconds, for tcp
%functions to complete.
%
%Return Value:
%instrument - tcpip object encapsulating the connection to the Hyperion
%unit

switch port
    case 'commandPort'
        portInt = 51971;
    case 'peakStream'
        portInt = 51972;
    case 'spectrumStream'
        portInt = 51973;
    otherwise
        disp(sprintf(['Incorrect value for port.  Possible values are\n',...
            'commandPort, peakStream, or spectrumStream']))
        portInt = 0;
end
        
if portInt        

    instrument = tcpip(address, portInt,'Timeout', timeout, 'InputBufferSize', 32768);
    fopen(instrument);
    
else
    disp('Instrument not connected')
    instrument = 0;
end
