%This will acquire spectra for one or more channels, apply the calibration
%scale and offset, and then plot the data.

address = '10.0.41.3';
scanRate = 10;
%This is the list of channels for which spectra will be returned.
channelList = [1:15];

hyperionInstrument = hCOMMOpenConnection(address, 'commandPort', 1);

%Setting the laser scan speed can take a few seconds.  Uncomment this only
%if you need to change the scan rate.
%response = hACQSetLaserScanSpeed(hyperionInstrument, scanRate);
%disp(char(response.message'))

try
    %Get the power calibration data.  This is constant and will not change
    %for a given instrument unless it is recalibrated by MOI
    
    [offset, scale] = hACQGetPowerCalibrationInfo(hyperionInstrument);

    [spectrum, header] = hACQGetSpectrum(hyperionInstrument, channelList, 1);
    
    %Apply the calibration scale and offset
    
    spectrum = double(spectrum)./(ones(header.numPoints,1)*double(scale(channelList))) + ...
    ones(header.numPoints,1)*double(offset(channelList));
    wavelengths = double(header.startWavelength) + double(0:header.numPoints-1)*header.wavelengthIncrement;
    plot(wavelengths,spectrum)
catch err
    disp(err.message)
end

hCOMMCloseConnection(hyperionInstrument);